==> spring-boot-ext-1.2.57-sources.jar: cn/com/duibaboot/ext/autoconfigure/data/elasticsearch/ElasticsearchDataAutoConfiguration.java <==
package cn.com.duibaboot.ext.autoconfigure.data.elasticsearch;

import org.elasticsearch.client.Client;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.data.elasticsearch.ElasticsearchAutoConfiguration;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.elasticsearch.core.convert.ElasticsearchConverter;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年05月02日 10:22
 * @descript:
 * @version: 1.0
 */
@Configuration
@ConditionalOnClass({ Client.class, org.springframework.data.elasticsearch.core.ElasticsearchTemplate.class })
@AutoConfigureAfter(ElasticsearchAutoConfiguration.class)
@AutoConfigureBefore(org.springframework.boot.autoconfigure.data.elasticsearch.ElasticsearchDataAutoConfiguration.class)
@EnableConfigurationProperties(ElasticsearchProperties.class)
public class ElasticsearchDataAutoConfiguration {

    @Autowired
    private ElasticsearchProperties elasticsearchProperties;

    @Bean
    @ConditionalOnMissingBean
    @ConditionalOnBean({Client.class, ElasticsearchConverter.class})
    public ElasticsearchTemplate elasticsearchTemplate(Client client, ElasticsearchConverter converter) {
        try {
            return new ElasticsearchTemplate(client, converter,elasticsearchProperties.getSearchTimeout());
        }
        catch (Exception ex) {
            throw new IllegalStateException(ex);
        }
    }
}

==> spring-boot-ext-1.3.14.8-sources.jar: cn/com/duibaboot/ext/autoconfigure/data/elasticsearch/ElasticsearchDataAutoConfiguration.java <==
package cn.com.duibaboot.ext.autoconfigure.data.elasticsearch;

import org.elasticsearch.client.Client;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.data.elasticsearch.ElasticsearchAutoConfiguration;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.elasticsearch.core.ElasticsearchOperations;
import org.springframework.data.elasticsearch.core.convert.ElasticsearchConverter;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年05月02日 10:22
 * @descript:
 * @version: 1.0
 */
@Configuration
@ConditionalOnClass({ Client.class, org.springframework.data.elasticsearch.core.ElasticsearchTemplate.class })
@AutoConfigureAfter(ElasticsearchAutoConfiguration.class)
@AutoConfigureBefore(org.springframework.boot.autoconfigure.data.elasticsearch.ElasticsearchDataAutoConfiguration.class)
@EnableConfigurationProperties(ElasticsearchProperties.class)
public class ElasticsearchDataAutoConfiguration {

    @Autowired
    private ElasticsearchProperties elasticsearchProperties;

    @Bean
    @ConditionalOnMissingBean({CustomElasticsearchTemplate.class, org.springframework.data.elasticsearch.core.ElasticsearchTemplate.class, ElasticsearchOperations.class})
    @ConditionalOnBean({Client.class, ElasticsearchConverter.class})
    public CustomElasticsearchTemplate elasticsearchTemplate(Client client, ElasticsearchConverter converter) {
        try {
            CustomElasticsearchTemplate t =  new CustomElasticsearchTemplate(client, converter,elasticsearchProperties.getSearchTimeout());
            t.setSearchTimeout(elasticsearchProperties.getSearchTimeout());
            return t;
        }
        catch (Exception ex) {
            throw new IllegalStateException(ex);
        }
    }
}
